@@ -210,9 +210,13 @@ read_abs <- function(cat_no = NULL,
     .f = get_abs_xml_metadata
   )
 
+  # Ensure we're not getting spurious matches of table numbers
+  if (tables != "all" && is.null(series_id)) {
+    xml_dfs <- xml_dfs[match_tables(xml_dfs$TableTitle, tables), ]
+  }
+
   # the same Series ID can appear in multiple spreadsheets;
   # we just want one (the latest)
-
   if (!is.null(series_id)) {
     xml_dfs <- xml_dfs %>%
       dplyr::group_by(SeriesID) %>%
@@ -301,3 +305,17 @@ read_abs_series <- function(series_id, ...) {
   read_abs(series_id = series_id,
            ...)
 }
+
+match_tables <- function(table_list, requested_tables) {
+  requested <- paste0(requested_tables, collapse = "|")
+  # Looking for table number preceded by a space or a 0, and
+  # followed my a full stop or a space
+  regex_pattern <- paste0("(?<=\\s|0)",
+                          "(", requested, ")",
+                          "(?=\\.|\\s)")
+
+  predot_matches <- regexpr(".*\\.", table_list)
+  table_list_predot <- regmatches(table_list, m = predot_matches)
+
+  grepl(regex_pattern, table_list_predot, perl = TRUE, ignore.case = TRUE)
+}
