@@ -16,6 +16,8 @@
 #' \itemize{
 #'  \item{"industry_jobs"}{ Payroll jobs by industry division, state, sex, and age
 #'  group (Table 4)}
+#'  \item{"industry_wages"}{ Total wages by industry division, state, sex, and age
+#'  group (Table 4)}
 #'  \item{"sa4_jobs"}{ Payroll jobs by statistical area 4 (SA4) and state (Table 5)}
 #'  \item{"sa3_jobs}{ Payroll jobs by statistical area 4 (SA4), statistical
 #'  area 3 (SA3), and state (Table 5)}
@@ -23,6 +25,9 @@
 #'  industry division (Table 6)}
 #'  \item{"empsize_jobs"}{ Payroll jobs by size of employer (number of
 #'  employees) and state (Table 7)}
+#'  \item{"gccsa_jobs"}{ Payroll jobs by Greater Capital City Statistical
+#'  Area (Table 5)}
+#'  \item{"sex_age_jobs}{ Payroll jobs by sex and age (Table 8)}
 #' }
 #' The default is "industry_jobs".
 #' @return A tidy (long) `tbl_df`. The number of columns differs based on the `series`.
@@ -47,10 +52,13 @@
 
 read_payrolls <- function(series = c(
                             "industry_jobs",
+                            "industry_wages",
                             "sa4_jobs",
                             "sa3_jobs",
                             "subindustry_jobs",
-                            "empsize_jobs"
+                            "empsize_jobs",
+                            "gccsa_jobs",
+                            "sex_age_jobs"
                           ),
                           path = Sys.getenv("R_READABS_PATH",
                             unset = tempdir()
@@ -61,10 +69,13 @@ read_payrolls <- function(series = c(
 
   cube_name <- switch(series,
     "industry_jobs" = "DO004",
+    "industry_wages" = "DO004",
     "sa4_jobs" = "DO005",
     "sa3_jobs" = "DO005",
     "subindustry_jobs" = "DO006",
-    "empsize_jobs" = "DO007"
+    "empsize_jobs" = "DO007",
+    "gccsa_jobs" = "DO005",
+    "sex_age_jobs" = "DO008"
   )
 
   safely_download_cube <- purrr::safely(.f = ~ download_abs_data_cube(
@@ -97,10 +108,13 @@ read_payrolls <- function(series = c(
 
   sheet_name <- switch(series,
     "industry_jobs" = "Payroll jobs index",
-    "sa4_jobs" = "Payroll jobs index-SA4",
-    "sa3_jobs" = "Payroll jobs index-SA3",
+    "industry_wages" = "Total wages index",
+    "sa4_jobs" = "SA4",
+    "sa3_jobs" = "SA3",
     "subindustry_jobs" = "Payroll jobs index-Subdivision",
-    "empsize_jobs" = "Employment size"
+    "empsize_jobs" = "Employment size",
+    "gccsa_jobs" = "GCCSA",
+    "sex_age_jobs" = "5 year age groups"
   )
 
   cube <- read_payrolls_local(
